@@ -14,6 +14,9 @@
 #include "version.h"
 /***** probably needs to be protected by check that dirent is available */
 #include <dirent.h>
+#ifdef __FreeBSD__
+#include <floatingpoint.h>
+#endif
 
 extern VOID StPollEvent(V);
 extern int StBlockForInput(V);
@@ -54,6 +57,9 @@ VOID osinit(name)
   time_stamp = time((time_t *) 0);
   
   disable_interrupts();
+#ifdef __FreeBSD__
+  fpsetmask(0);
+#endif
   if (signal(SIGINT, SIG_IGN) != SIG_IGN)
     signal(SIGINT, intercatch);
   signal(SIGFPE, fpecatch);
@@ -71,7 +77,7 @@ VOID osfinish()
 {
   CONTEXT cntxt;
   xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,(LVAL)1);
-  if (setjmp(cntxt.c_jmpbuf))
+  if (XL_SETJMP(cntxt.c_jmpbuf))
     exit(0);
   if (s_breakenable != NULL) setvalue(s_breakenable, NIL);
 #ifdef CONDITIONS
