@@ -420,7 +420,7 @@ VOID osfinish(void)
 {
   CONTEXT cntxt;
   xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,(LVAL)1);
-  if (setjmp(cntxt.c_jmpbuf))
+  if (XL_SETJMP(cntxt.c_jmpbuf))
     exit(0);
   if (s_breakenable != NULL) setvalue(s_breakenable, NIL);
 #ifdef CONDITIONS
@@ -2083,14 +2083,14 @@ static pascal OSErr handleDOSC(AppleEvent *evt, AppleEvent *reply, long ref)
   /* since it is no longer possible to tell reliably whether the jump is an    */
   /* error or a GO to the 8th tag (I think).                                   */
   xlbegin(&ucntxt, CF_UNWIND, NIL);
-  if (setjmp(ucntxt.c_jmpbuf)) {
+  if (XL_SETJMP(ucntxt.c_jmpbuf)) {
     apple_event_status = AE_UNWIND;
     /**** make a better reply here */
     err = errAEEventNotHandled;
   }
   else {
     xlbegin(&ecntxt, CF_ERROR, s_true);
-    if (setjmp(ecntxt.c_jmpbuf)) {
+    if (XL_SETJMP(ecntxt.c_jmpbuf)) {
       apple_event_status = AE_ERROR;
       err = errAEEventNotHandled;
     }
