@@ -24,6 +24,8 @@
 
 #define MAXFILESIZE 31000 /**** about max a win16 edit control can handle */
 
+#ifndef RC_INVOKED
 int WINAPI	WinMain(HINSTANCE, HINSTANCE, LPSTR, int);
 LONG CALLBACK	MainWndProc(HWND, UINT, WPARAM, LONG);
 BOOL CALLBACK	About(HWND, UINT, WPARAM, LONG);
+#endif
