@@ -1357,7 +1357,7 @@ static void StGWPrint(StGWWinInfo *gwinfo)
       LVAL val;
 
       xlbegin(&cntxt,CF_UNWIND,NIL);
-      if (setjmp(cntxt.c_jmpbuf)) {
+      if (XL_SETJMP(cntxt.c_jmpbuf)) {
 	target = xltarget;
 	mask = xlmask;
 	val = xlvalue;
