@@ -79,7 +79,7 @@ void osfinish()
 {
   CONTEXT cntxt;
   xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,(LVAL)1);
-  if (setjmp(cntxt.c_jmpbuf))
+  if (XL_SETJMP(cntxt.c_jmpbuf))
     exit(0); /*** this probably needs to be done differently */
   if (s_breakenable != NULL) setvalue(s_breakenable, NIL);
 #ifdef CONDITIONS
@@ -400,7 +400,7 @@ LVAL readevalstream(LVAL stream)
 
   /* read and evaluate each expression in the stream */
   xlbegin(&cntxt,CF_ERROR,s_true);
-  if (! setjmp(cntxt.c_jmpbuf)) {
+  if (! XL_SETJMP(cntxt.c_jmpbuf)) {
     while (xlread(stream,&expr,FALSE,FALSE)) {
       val = xleval(expr);
     }
