@@ -255,3 +255,15 @@ void StWGetSize(HWND w, int *pwidth, int *pheight, int frame)
   if (pwidth) *pwidth = width;
   if (pheight) *pheight = height;
 }
+
+LVAL msw_main_frame_visible(void)
+{
+  if (moreargs()) {
+    if (xlgetarg() != NIL)
+      ShowWindow(hWndFrame, IsIconic(hWndFrame) ? SW_SHOWNORMAL : SW_SHOW);
+    else
+      ShowWindow(hWndFrame, SW_HIDE);
+  }
+  xllastarg();
+  return IsWindowVisible(hWndFrame) ? s_true : NIL;
+}
