@@ -46,7 +46,7 @@ extern LVAL s_in_callback;
 
 static DWORD ddeInst = 0;
 static HSZ service, systopic;
-static jmp_buf exit_tag;
+static XL_JMP_BUF exit_tag;
 
 /* forward declarations */
 static BOOL CheckSystem(void);
@@ -88,6 +88,10 @@ int WINAPI WinMain(HINSTANCE hInstance,
     if (! InitApplication(hInstance))
       return(FALSE);
 
+  /* check for the COM embedding flag; start invisible if it is there */
+  if (strstr(lpCmdLine, "-Embedding") != NULL)
+    nCmdShow = SW_HIDE;
+
   /* initialize the specific instance */
   if (! InitInstance(hInstance, nCmdShow))
     return(FALSE);
@@ -152,7 +156,7 @@ int WINAPI WinMain(HINSTANCE hInstance,
     }
   }
 
-  if (setjmp(exit_tag) == 0)
+  if (XL_SETJMP(exit_tag) == 0)
     xlsmain(argc, argv);
 
   /* process orderly shutdown */
@@ -185,7 +189,7 @@ int WINAPI WinMain(HINSTANCE hInstance,
 
 void ExitXLS(void)
 {
-  longjmp(exit_tag, 1);
+  XL_LONGJMP(exit_tag, 1);
 }
 
 static BOOL CheckSystem(void)
@@ -255,6 +259,7 @@ static BOOL InitInstance(HANDLE hInstance, int nCmdShow)
 {
   MDICREATESTRUCT mdicreate;
   RECT r;
+  DWORD flags;
 
   hInst = hInstance;
 
@@ -269,6 +274,19 @@ static BOOL InitInstance(HANDLE hInstance, int nCmdShow)
     defaultpath = malloc(strlen(buf) + 1);
     strcpy(defaultpath, buf);
   }
+#ifdef WIN32
+  else {
+    char buf[_MAX_PATH+1];
+    char drive[_MAX_PATH+1];
+    char dir[_MAX_PATH+1];
+    GetModuleFileName(NULL, buf, sizeof(buf));
+    _splitpath(buf, drive, dir, NULL, NULL);
+    if ((defaultpath = malloc(strlen(drive) + strlen(dir) + 1)) != NULL) {
+      strcpy(defaultpath, drive);
+      strcat(defaultpath, dir);
+    }
+  }
+#endif /* WIN32 */
 
   if (GetPrivateProfileString(xlispSection, "Workspace", "", buf, 128, iniFile)) {
     resfile = malloc(strlen(buf) + 1);
@@ -295,10 +313,11 @@ static BOOL InitInstance(HANDLE hInstance, int nCmdShow)
   hWinMenu = GetSubMenu(hMainMenu, GetMenuItemCount(hMainMenu) - 1);
 
   /* create MDI frame for this instance */
+  flags = WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN | MDIS_ALLCHILDSTYLES;
+  if (nCmdShow == SW_HIDE) flags |= WS_MINIMIZE;
   hWndFrame = CreateWindow(szFrameClass,
 			   "XLISP-STAT",
-			   WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN |
-                           MDIS_ALLCHILDSTYLES,
+			   flags,
 			   CW_USEDEFAULT,
 			   CW_USEDEFAULT,
 			   CW_USEDEFAULT,
@@ -456,6 +475,7 @@ LONG CALLBACK FrameWndProc(HWND hWnd, UINT message, WPARAM wParam, LONG lParam)
       break;
     if (OKorCancelBox("Do you really want to quit?") == IDCANCEL)
       return(0);
+    do_exits();
     Exiting = TRUE;
     break;
   case WM_DESTROY:
@@ -584,7 +604,7 @@ HDDEDATA CALLBACK DdeProc(UINT type, UINT fmt, HCONV hconv,
     {
       CONTEXT cntxt;
       xlbegin(&cntxt, CF_UNWIND | CF_ERROR, NIL);
-      if (setjmp(cntxt.c_jmpbuf))
+      if (XL_SETJMP(cntxt.c_jmpbuf))
 	success = FALSE;
       else {
 	FRAMEP newfp;
@@ -700,7 +720,7 @@ HDDEDATA CALLBACK DdeProc(UINT type, UINT fmt, HCONV hconv,
 	 stops here. I think this is safe as far as XLISP is
 	 concerned; it is necessary for self sends to work properly.  */
 	xlbegin(&cntxt, CF_UNWIND | CF_ERROR, NIL);
-	if (setjmp(cntxt.c_jmpbuf))
+	if (XL_SETJMP(cntxt.c_jmpbuf))
 	  success = FALSE;
 	else {
 	  LVAL olddenv = xldenv;
@@ -735,7 +755,7 @@ HDDEDATA CALLBACK DdeProc(UINT type, UINT fmt, HCONV hconv,
 	   stops here. I think this is safe as far as XLISP is
 	   concerned; it is necessary for self sends to work properly.  */
 	xlbegin(&cntxt, CF_UNWIND | CF_ERROR, NIL);
-	if (setjmp(cntxt.c_jmpbuf))
+	if (XL_SETJMP(cntxt.c_jmpbuf))
 	  result = NULL;
 	else {
 	  LVAL olddenv = xldenv;
@@ -861,10 +881,11 @@ static void mainloop(void)
       MSWDoIdleActions();
       MSWDoEventQueue();
     }
-    if (! MSWAnyIdleActions() && ! MSWAnyEventsQueued()
+    if (! Exiting && ! MSWAnyIdleActions() && ! MSWAnyEventsQueued()
         && GetMessage(&msg, 0, 0, 0)) {
       if (handle_message(&msg)) break;
     }
+    if (Exiting) xexit();
   }
 }
 
@@ -999,7 +1020,7 @@ LVAL dde_services(void)
   xllastarg();
 
   xlbegin(&cntxt,CF_UNWIND,NIL);
-  if (setjmp(cntxt.c_jmpbuf)) {
+  if (XL_SETJMP(cntxt.c_jmpbuf)) {
     jumping = TRUE;
     target = xltarget;
     mask = xlmask;
@@ -1132,7 +1153,7 @@ LVAL dde_client_transaction(void)
     else hsz = NULL;
 
     xlbegin(&cntxt,CF_UNWIND,NIL);
-    if (setjmp(cntxt.c_jmpbuf)) {
+    if (XL_SETJMP(cntxt.c_jmpbuf)) {
       jumping = TRUE;
       target = xltarget;
       mask = xlmask;
