@@ -14,6 +14,9 @@
 #include <sys/stat.h>
 /***** probably needs to be protected by check that dirent is available */
 #include <dirent.h>
+#ifdef __FreeBSD__
+#include <floatingpoint.h>
+#endif
 
 #include "xlisp.h"
 #include "osdefs.h"
@@ -89,6 +92,9 @@ VOID osinit(name)
   time_stamp = time((time_t *) 0);
   
   disable_interrupts();
+#ifdef __FreeBSD__
+  fpsetmask(0);
+#endif
   if (signal(SIGINT, SIG_IGN) != SIG_IGN)
     signal(SIGINT, intercatch);
   signal(SIGFPE, fpecatch);
