@@ -1818,7 +1818,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	
 	xlbegin(&cntxt, CF_THROW, tag);
 	state.li = li; state.cpc = current_pc;
-	sts = setjmp(cntxt.c_jmpbuf);
+	sts = XL_SETJMP(cntxt.c_jmpbuf);
 	li = state.li; current_pc = state.cpc;
 	if (! sts)
 	  bcloop(li);
@@ -1855,7 +1855,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	
 	/* check for a go */
 	state.li = li; state.ci = ci; state.ti = ti; state.cpc = current_pc;
-	sts = setjmp(cntxt.c_jmpbuf);
+	sts = XL_SETJMP(cntxt.c_jmpbuf);
 	li = state.li; ci = state.ci; ti = state.ti; current_pc = state.cpc;
 	if (sts) {
 	  restore_continuation(old_cstop);
@@ -1910,7 +1910,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	xlbegin(&cntxt,CF_UNWIND,NIL);
 	state.l1i = l1i; state.l2i = l2i; state.ui = ui;
 	state.cpc = current_pc;
-	sts = setjmp(cntxt.c_jmpbuf);
+	sts = XL_SETJMP(cntxt.c_jmpbuf);
 	l1i = state.l1i; l2i = state.l2i; ui = state.ui;
 	current_pc = state.cpc;
 	if (sts) {
@@ -2054,7 +2054,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	
 	xlbegin(&cntxt, CF_THROW, tag);
 	state.li = li; state.cpc = current_pc;
-	sts = setjmp(cntxt.c_jmpbuf);
+	sts = XL_SETJMP(cntxt.c_jmpbuf);
 	li = state.li; current_pc = state.cpc;
 	if (! sts)
 	  bcloop(li);
@@ -2127,7 +2127,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	
 	xlbegin(&cntxt, CF_ERROR, flag);
 	state.li = li; state.cpc = current_pc;
-	sts = setjmp(cntxt.c_jmpbuf);
+	sts = XL_SETJMP(cntxt.c_jmpbuf);
 	li = state.li; current_pc = state.cpc;
 	if (sts) {
 	  set_one_result(NIL);
@@ -2381,7 +2381,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	xlsave1(tag);
 	tag = consa(NIL);
 	xlbegin(&cntxt, CF_THROW, tag);
-	if (! setjmp(cntxt.c_jmpbuf))
+	if (! XL_SETJMP(cntxt.c_jmpbuf))
 	  xlapp1(getregval(bi), tag); /**** inefficient but easy */
 	/* vsbase needs to be restored in jumps. xlcstop is handled in
            the standard jump code, as is vstop = xlsp */
@@ -2404,7 +2404,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	xlsave1(tag);
 	tag = consa(NIL);
 	xlbegin(&cntxt, CF_THROW, tag);
-	if (setjmp(cntxt.c_jmpbuf)) {
+	if (XL_SETJMP(cntxt.c_jmpbuf)) {
 	  BC_evfun(xlvalue, 0, xlsp);
 	  /* vsbase needs to be restored in jumps. xlcstop is handled in
 	     the standard jump code, as is vstop = xlsp */
@@ -2440,7 +2440,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	get_operand(bi);
 	get_operand(ci);
 	xlbegin(&cntxt, CF_THROW, getregval(ti));
-	if (! setjmp(cntxt.c_jmpbuf))
+	if (! XL_SETJMP(cntxt.c_jmpbuf))
 	  BC_evfun(getregval(bi), 0, xlsp);
 	/* vsbase needs to be restored in jumps. xlcstop is handled in
            the standard jump code, as is vstop = xlsp */
@@ -2460,7 +2460,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	get_operand(fi);
 	get_operand(ci);
 	xlbegin(&cntxt, CF_ERROR, getregval(fi));
-	if (setjmp(cntxt.c_jmpbuf)) {
+	if (XL_SETJMP(cntxt.c_jmpbuf)) {
 	  set_one_result(NIL);
 	  /* vsbase needs to be restored in jumps. xlcstop is handled in
 	     the standard jump code, as is vstop = xlsp */
@@ -2488,7 +2488,7 @@ LOCAL VOID bcloop P1C(int, entry)
 	get_operand(pi);
 	get_operand(ci);
 	xlbegin(&cntxt,CF_UNWIND,NIL);
-	if (setjmp(cntxt.c_jmpbuf)) {
+	if (XL_SETJMP(cntxt.c_jmpbuf)) {
 	  sts = TRUE;
 	  target = xltarget;
 	  mask = xlmask;
