@@ -55,7 +55,7 @@ LVAL copybignum P2C(LVAL, x, int, s)
   LVAL b = newbignum(getbignumsize(x));
   MEMCPY(getbignumarray(b), getbignumarray(x),
 	 (getbignumsize(x)+1)*sizeof(BIGNUMDATA));
-  *getbignumarray(b) = s;
+  *getbignumarray(b) = (BIGNUMDATA) s;
   return b;
 }
 
@@ -84,7 +84,7 @@ LVAL normalBignum P1C(LVAL, x)
   xlprot1(x);
   newobj = newbignum(sizex);
   nd = getbignumarray(newobj);
-  *nd++ = signx;
+  *nd++ = (BIGNUMDATA) signx;
   MEMCPY(nd, xd, sizex*sizeof(short));
   xlpop();
   return newobj;
@@ -137,7 +137,7 @@ LVAL cvtulongbignum P2C(unsigned long, n, int, sign)
   BIGNUMDATA *v = getbignumarray(x);
   int i;
 
-  *v++ = sign;
+  *v++ = (BIGNUMDATA) sign;
   v += FIXBIGDIGS - 1;  /* advance to point to least significant digit */
   for (i = 0; i < FIXBIGDIGS; i++, n >>= 16)
     *v-- = (BIGNUMDATA)(n & 0xffff);
@@ -224,15 +224,15 @@ LVAL cvtflobignum P1C(FLOTYPE, n)
   v = getbignumarray(x);
 
   /* set sign */
-  *v++ = n<0;
+  *v++ = (BIGNUMDATA) (n<0);
 
   /* adjust the exponent */
   if (shift < 16)
-    mantissa = ldexp(mantissa, -shift);
+    mantissa = LDEXP(mantissa, -shift);
 
   /* compute bignum digits */
   for (; size > 0 && mantissa != 0.0; size--, v++) {
-    mantissa = ldexp(mantissa, 16);
+    mantissa = LDEXP(mantissa, 16);
     *v = (BIGNUMDATA) mantissa;
     mantissa -= *v;
   }
@@ -312,11 +312,11 @@ LVAL cvtstrbignum P2C(char *, s, int, radix)
 
   while (*s == '0') s++;	/* delete leading zeroes */
 
-  size = STRLEN(s)*log((double)radix)/log(65536.0) + 1;
+  size = (int)(STRLEN(s)*log((double)radix)/log(65536.0)) + 1;
   if (size==1) size = 2;
   x = newbignum(size);
   v = getbignumarray(x);
-  *v++ = sign;
+  *v++ = (BIGNUMDATA) sign;
   size--;
   while((i=*s++)!=0) {
     if (ISLOWER7(i)) i = toupper(i);
@@ -396,9 +396,9 @@ char *cvtbignumstr P2C(LVAL, x, int, radix)
     d2 = r;
     for (i = digits; i > 0; i--) {
       if (d2==0 && zcheck < 0) break; /* no leading zeroes */
-      r = d2 % radix;
-      d2 = d2 / radix;
-      *--cp = (r<10 ? r + '0' : r - 10 + 'A');
+      r = (BIGNUMDATA) (d2 % radix);
+      d2 = (BIGNUMDATA) (d2 / radix);
+      *--cp = (char)(r<10 ? r + '0' : r - 10 + 'A');
     }
     if (zcheck>0) {		/* reduce dividend size if possible */
       v += zcheck;
@@ -451,13 +451,13 @@ LOCAL LVAL ashbignum P2C(LVAL, ux, FIXTYPE, count)
   }
   wx = newbignum(wsize);
   w = getbignumarray(wx);
-  *w++ = signu;
+  *w++ = (BIGNUMDATA) signu;
 
   if (count>0 && bitshift) {
-    w[0] = u[0] >> (16-bitshift);
+    w[0] = (BIGNUMDATA) (u[0] >> (16-bitshift));
     for (i=1; i<usize; i++)
-      w[i] = (u[i-1] << bitshift) + (u[i] >> (16-bitshift));
-    w[usize] = u[usize-1] << bitshift;
+      w[i] = (BIGNUMDATA)((u[i-1] << bitshift) + (u[i] >> (16-bitshift)));
+    w[usize] = (BIGNUMDATA) (u[usize-1] << bitshift);
   }
   else if (count > 0) {		/* no bitshift */
     MEMCPY(w, u, usize*sizeof(BIGNUMDATA));
@@ -467,10 +467,10 @@ LOCAL LVAL ashbignum P2C(LVAL, ux, FIXTYPE, count)
       lowdata = 0;	/* if we "shift out" nonzero, need to subtract one
 			   from the result */
       for (i=usize-fullshift; i < usize; i++) lowdata |= u[i];
-      lowdata |= u[usize-fullshift-1] << (16-bitshift);
-      w[1] = u[0] >> bitshift;
+      lowdata |= (BIGNUMDATA) (u[usize-fullshift-1] << (16-bitshift));
+      w[1] = (BIGNUMDATA) (u[0] >> bitshift);
       for (i=2; i<wsize; i++)
-	w[i] = (u[i-2] << (16-bitshift)) + (u[i-1] >> bitshift);
+	w[i] = (BIGNUMDATA)((u[i-2] << (16-bitshift)) + (u[i-1] >> bitshift));
       if (lowdata) {
 	carry = 1;
 	for (i=wsize-1; i>=0; i--) {
@@ -484,9 +484,9 @@ LOCAL LVAL ashbignum P2C(LVAL, ux, FIXTYPE, count)
 	wx = normalBignum(wx);
     }
     else {
-      w[adj] = u[0] >> bitshift;
+      w[adj] = (BIGNUMDATA) (u[0] >> bitshift);
       for (i=1; i<wsize; i++)
-	w[i+adj] = (u[i-1] << (16-bitshift)) + (u[i] >> bitshift);
+	w[i+adj] = (BIGNUMDATA)((u[i-1] << (16-bitshift)) + (u[i] >> bitshift));
     }
   }
   else {		/* right shift without bitshift */
@@ -517,8 +517,8 @@ LOCAL LVAL logbignum P3C(LVAL, ux, LVAL, vx, LOGFUNCTION, logfcn)
 {
   BIGNUMDATA *u = getbignumarray(ux);
   BIGNUMDATA *v = getbignumarray(vx);
-  BIGNUMDATA signu = *u++ ? 0xffff : 0;
-  BIGNUMDATA signv = *v++ ? 0xffff : 0;
+  BIGNUMDATA signu = (BIGNUMDATA) (*u++ ? 0xffff : 0);
+  BIGNUMDATA signv = (BIGNUMDATA) (*v++ ? 0xffff : 0);
   int usize = (int) getbignumsize(ux);
   int vsize = (int) getbignumsize(vx);
   int wsize;
@@ -539,7 +539,7 @@ LOCAL LVAL logbignum P3C(LVAL, ux, LVAL, vx, LOGFUNCTION, logfcn)
   if (wsize<2) wsize=2;
   wx = newbignum(wsize);
   w = getbignumarray(wx);
-  *w++ = signw != 0;
+  *w++ = (BIGNUMDATA) (signw != 0);
 
   for (i=wsize-1, j=usize-1, k=vsize-1; i>=0; i--, j--, k--) {
     if (j<0) n1 = signu;
@@ -590,37 +590,37 @@ LOCAL BIGNUMDATA xorfcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 
 LOCAL BIGNUMDATA eqvfcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return ~(x ^ y);
+  return (BIGNUMDATA) ~(x ^ y);
 }
 
 LOCAL BIGNUMDATA nandfcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return ~(x & y);
+  return (BIGNUMDATA) ~(x & y);
 }
 
 LOCAL BIGNUMDATA norfcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return ~(x | y);
+  return (BIGNUMDATA) ~(x | y);
 }
 	
 LOCAL BIGNUMDATA andc1fcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return (~x) & y;
+  return (BIGNUMDATA)((~x) & y);
 }
 
 LOCAL BIGNUMDATA andc2fcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return x & (~y);
+  return (BIGNUMDATA) (x & (~y));
 }
 
 LOCAL BIGNUMDATA orc1fcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return (~x) | y;
+  return (BIGNUMDATA)((~x) | y);
 }
 
 LOCAL BIGNUMDATA orc2fcn P2C(BIGNUMDATA, x, BIGNUMDATA, y)
 {
-  return x | (~y);
+  return (BIGNUMDATA) (x | (~y));
 }
 
 LVAL addsubbignum P3C(LVAL, ux, LVAL, vx, int, subvflag)
@@ -656,13 +656,13 @@ LVAL addsubbignum P3C(LVAL, ux, LVAL, vx, int, subvflag)
 	(vsize==usize && v[0] > 32767)) {
       wx = newbignum(usize+1);
       w = getbignumarray(wx);
-      *w++ = signu;
+      *w++ = (BIGNUMDATA) signu;
       *w++ = 0;			/* skip carry location */
     }
     else {
       wx = newbignum(usize);
       w = getbignumarray(wx);
-      *w++ = signu;
+      *w++ = (BIGNUMDATA) signu;
     }
     carry = 0;
     for (j = usize-1, k=vsize-1; j >=0; j--, k--) {
@@ -703,7 +703,7 @@ LVAL addsubbignum P3C(LVAL, ux, LVAL, vx, int, subvflag)
     if (usize < 2) wsize = 2;
     wx = newbignum(wsize);
     w = getbignumarray(wx);
-    *w++ = signu;
+    *w++ = (BIGNUMDATA) signu;
     if (usize==1) w++;		/* skip leading cell */
 		
     carry = 0;
@@ -711,7 +711,7 @@ LVAL addsubbignum P3C(LVAL, ux, LVAL, vx, int, subvflag)
       if (k>=0) temp2 = (long)u[j] - v[k] - carry;
       else temp2 = (long)u[j] - carry;
       w[j] = (BIGNUMDATA) (temp2 & 0xffff);
-      carry = temp2 < 0;
+      carry = (BIGNUMDATA) (temp2 < 0);
     }
 
     /* we might need to normalize the bignum */
@@ -748,7 +748,7 @@ LVAL multbignum P2C(LVAL, ux, LVAL, vx)
 
   wx = newbignum(usize+vsize);
   w = getbignumarray(wx);
-  *w++ = sign;			/* sign is now taken care of */
+  *w++ = (BIGNUMDATA) sign;    /* sign is now taken care of */
 
   for (j=vsize-1; j>=0; j--) {
     for (k=0, i=usize-1; i>=0; i--) {
@@ -797,13 +797,13 @@ LVAL divbignum P3C(LVAL, ux, LVAL, vx, LVAL *, rem)
   if (qsize < 2) qsize = 2;
   qx = newbignum(qsize);
   q = getbignumarray(qx);
-  *q++ = sign;
+  *q++ = (BIGNUMDATA) sign;
   if (qsize > usize-vsize+1) q++; /* unused entry */
   rsize = vsize;
   if (rsize < 2) rsize = 2;
   *rem = rx = newbignum(rsize);
   r = getbignumarray(rx);
-  *r++ = rsign;
+  *r++ = (BIGNUMDATA) rsign;
   if (rsize > vsize) r++;	/* unused entry */
 
   if (vsize == 1) {
@@ -873,7 +873,7 @@ LVAL divbignum P3C(LVAL, ux, LVAL, vx, LVAL *, rem)
       k = (BIGNUMDATA)(t >> 16); /* upper part of product */
       t1 = (long)u[i+j+1] - (long)(t & 0xffff)  - (long)k2;
       u[i+j+1] = (BIGNUMDATA)(t1 & 0xffff);
-      k2 = t1 < 0;
+      k2 = (BIGNUMDATA) (t1 < 0);
     }
     t1 = (long)u[j] - (long)(k&0xffff) - (long)k2;
     u[j] = (BIGNUMDATA)(t1 & 0xffff);
@@ -886,7 +886,7 @@ LVAL divbignum P3C(LVAL, ux, LVAL, vx, LVAL *, rem)
 	u[i+j+1] = (BIGNUMDATA)(t & 0xffff);
 	k = (BIGNUMDATA) (t >> 16);
       }
-      u[j] = u[j] + k;
+      u[j] = (BIGNUMDATA) (u[j] + k);
     }
     q[j] = qest;
   }
