@@ -985,7 +985,7 @@ LOCAL LVAL prog P1C(int, pflag)
 
     /* establish a new execution context */
     xlbegin(&cntxt,CF_RETURN,NIL);
-    if (setjmp(cntxt.c_jmpbuf))
+    if (XL_SETJMP(cntxt.c_jmpbuf))
 	val = xlvalue;
     else {
 #ifdef LEXBIND
@@ -1222,7 +1222,7 @@ LVAL xloop(V)
 #endif
     /* establish a new execution context */
     xlbegin(&cntxt,CF_RETURN,NIL);
-    if (setjmp(cntxt.c_jmpbuf))
+    if (XL_SETJMP(cntxt.c_jmpbuf))
       val = xlvalue;
     else {
 #ifdef LEXBIND
@@ -1284,7 +1284,7 @@ LOCAL LVAL doloop P1C(int, pflag)
     /* establish a new execution context */
     xlbegin(&cntxt,CF_RETURN,NIL);
     state.blist = blist; state.clist = clist; state.test = test;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     blist = state.blist; clist = state. clist; test = state.test;
     if (sts)
 	val = xlvalue;
@@ -1377,7 +1377,7 @@ LVAL xdolist(V)
 
     /* establish a new execution context */
     xlbegin(&cntxt,CF_RETURN,NIL);
-    if (setjmp(cntxt.c_jmpbuf))
+    if (XL_SETJMP(cntxt.c_jmpbuf))
 	val = xlvalue;
     else {
 #ifdef LEXBIND
@@ -1450,7 +1450,7 @@ LVAL xdotimes(V)
 
     /* establish a new execution context */
     xlbegin(&cntxt,CF_RETURN,NIL);
-    if (setjmp(cntxt.c_jmpbuf))
+    if (XL_SETJMP(cntxt.c_jmpbuf))
 	val = xlvalue;
     else {
 #ifdef LEXBIND
@@ -1524,7 +1524,7 @@ LVAL xblock(V)
     /* execute the block */
     xlbegin(&cntxt,CF_RETURN,name);
     state.name = name;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     name = state.name;
     if (sts)
 	val = xlvalue;
@@ -1572,7 +1572,7 @@ LVAL xcatch(V)
     xlbegin(&cntxt,CF_THROW,tag);
 
     /* check for 'throw' */
-    if (setjmp(cntxt.c_jmpbuf))
+    if (XL_SETJMP(cntxt.c_jmpbuf))
 	val = xlvalue;
 
     /* otherwise, evaluate the remainder of the arguments */
@@ -1629,7 +1629,7 @@ LVAL xunwindprotect(V)
     /* evaluate the protected expression */
     xlbegin(&cntxt,CF_UNWIND,NIL);
     state.mask = mask; state.target = target;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     mask = state.mask; target = state.target;
     if (sts != 0) {
 	target = xltarget;
@@ -1689,7 +1689,7 @@ LVAL xerrset(V)
 
     /* check for error */
     state.expr = expr;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     expr = state.expr;
     if (sts)
 	val = NIL;
@@ -1888,10 +1888,10 @@ LOCAL VOID tagbody(V)
 #endif
     /* check for a 'go' */
 #ifdef CRAYCC
-    i = setjmp(cntxt.c_jmpbuf);
+    i = XL_SETJMP(cntxt.c_jmpbuf);
     if (i != 0) {
 #else
-    if ((i = setjmp(cntxt.c_jmpbuf))!=0) {
+    if ((i = XL_SETJMP(cntxt.c_jmpbuf))!=0) {
 #endif /* CRAYCC */
         xlargc -= i;    /* point to jump target */
         xlargv += i;
