@@ -1396,7 +1396,7 @@ LVAL xrestore(V)
     xlfail("restore not available");
     return(NIL); /* never returns */
 #else
-    extern jmp_buf top_level;
+    extern XL_JMP_BUF top_level;
     char *name;
 
     /* get the file name */
@@ -1409,7 +1409,7 @@ LVAL xrestore(V)
 
     /* return directly to the top level */
     dbgputstr("[ returning to the top level ]\n");  /* TAA MOD --was std out*/
-    longjmp(top_level,1);
+    XL_LONGJMP(top_level,1);
     return (NIL);   /* never executed, but avoids warning message */
 #endif /* XLISP_STAT */
 }
@@ -2641,7 +2641,7 @@ LVAL xrestore(V)
 
     /* return directly to the top level */
     dbgputstr("[ returning to the top level ]\n");  /* TAA MOD --was std out*/
-    longjmp(top_level,1);
+    XL_LONGJMP(top_level,1);
     return (NIL);   /* never executed, but avoids warning message */
 #endif /* XLISP_STAT */
 }
@@ -2930,7 +2930,7 @@ static VOID do_finalize(V)
 
   xlsave1(next);
   xlbegin(&cntxt,CF_UNWIND|CF_ERROR,NIL);
-  setjmp(cntxt.c_jmpbuf);
+  XL_SETJMP(cntxt.c_jmpbuf);
   while (consp(finalize_pending)) {
     next = finalize_pending;
     finalize_pending = cdr(next);
