@@ -608,12 +608,12 @@ LOCAL LVAL evfun P3C(LVAL, fun, int, argc, FRAMEP, argv)
     /* execute the block */
 #ifdef CRAYCC
     if (null(getname(fun))) goto noname;
-    if (setjmp(cntxt.c_jmpbuf))
+    if (XL_SETJMP(cntxt.c_jmpbuf))
         val = xlvalue;
     else {
     noname:
 #else
-    if (!null(getname(fun)) && setjmp(cntxt.c_jmpbuf))
+    if (!null(getname(fun)) && XL_SETJMP(cntxt.c_jmpbuf))
 	val = xlvalue;
     else {
 #endif /* CRAYCC */
@@ -1202,7 +1202,7 @@ LVAL evmethod(obj,msgcls,message)
         xlbegin(&cntxt,CF_RETURN,name);
 
     /* execute the block */
-    if (!null(name) && setjmp(cntxt.c_jmpbuf))
+    if (!null(name) && XL_SETJMP(cntxt.c_jmpbuf))
         val = xlvalue;
     else {
 #ifdef LEXBIND
