@@ -142,9 +142,11 @@ LVAL k_symbol_macro=NULL;
 LVAL a_adata=NULL;
 #endif /* XLISP_STAT */
 LVAL a_ptr=NULL;
+LVAL a_weakbox=NULL;
 LVAL a_tvec=NULL;
 LVAL s_c_char=NULL,s_c_short=NULL,s_c_int=NULL,s_c_long=NULL,s_c_float=NULL,
-  s_c_double=NULL,s_c_complex=NULL,s_c_dcomplex=NULL,s_make_array=NULL;
+  s_c_double=NULL,s_c_complex=NULL,s_c_dcomplex=NULL,s_make_array=NULL,
+  s_c_uchar=NULL;
 
 /* Object system */
 LVAL s_self=NULL,k_new=NULL,k_isnew=NULL;
@@ -216,7 +218,7 @@ int lposition = 0;              /* postition in screen */
 /* From Luke Tierney, 9/93 */
 /* startup functions and command line symbols */
 LVAL s_startup_functions=NULL, s_command_line=NULL;
-LVAL s_loadfileargs=NULL, s_toplevelloop=NULL;
+LVAL s_loadfileargs=NULL, s_toplevelloop=NULL, s_exit_functions = NULL;
 
 /* general purpose string buffer */
 char buf[STRMAX*2+1] = { 0 };
