@@ -113,6 +113,7 @@ XLGLOBAL LVAL a_adata;
 XLGLOBAL char *defaultpath;
 #endif /* XLISP_STAT */
 XLGLOBAL LVAL a_ptr;
+XLGLOBAL LVAL a_weakbox;
 #ifdef HASHFCNS
 XLGLOBAL LVAL k_rhthresh, k_rhsize;
 #endif
@@ -121,7 +122,7 @@ XLGLOBAL LVAL a_array;        /* L. Tierney */
 XLGLOBAL LVAL s_vardoc;
 XLGLOBAL LVAL a_tvec;
 XLGLOBAL LVAL s_c_char, s_c_short, s_c_int, s_c_long, s_c_float, s_c_double;
-XLGLOBAL LVAL s_c_complex, s_c_dcomplex, s_make_array;
+XLGLOBAL LVAL s_c_complex, s_c_dcomplex, s_make_array, s_c_uchar;
 #ifdef IEEEFP
 XLGLOBAL LVAL s_posinfinity, s_neginfinity, s_notanumber;
 #endif
@@ -227,7 +228,7 @@ XLGLOBAL int lposition;	    /* postition in screen */
 /* From Luke Tierney, 9/93 */
 /* startup functions and command line symbols */
 XLGLOBAL LVAL s_startup_functions, s_command_line;
-XLGLOBAL LVAL s_loadfileargs, s_toplevelloop;
+XLGLOBAL LVAL s_loadfileargs, s_toplevelloop, s_exit_functions;
 
 /* general purpose string buffer */
 XLGLOBAL char buf[];
@@ -256,7 +257,7 @@ XLGLOBAL unsigned char ascii8cnv[];
 
 /* defined in xlisp.c */
 #ifdef SAVERESTORE
-XLGLOBAL jmp_buf top_level;
+XLGLOBAL XL_JMP_BUF top_level;
 #endif
 
 /* defined in xlftab.c */
