@@ -198,7 +198,8 @@ int xlisave P1C(char *, fname)
             case STREAM:
                 if (getfile(p) > CONSOLE ) {
 		    long offset;
-                    OSWRITE(filetab[getfile(p)].tname,1,FNAMEMAX,fp);
+		    strcpy(buf, filetab[getfile(p)].tname);
+                    OSWRITE(buf,1,FNAMEMAX,fp);
                     offset = OSTELL(getfile(p));
                     OSWRITE(&offset,1,sizeof(long),fp);
 	    }
