@@ -422,6 +422,8 @@ noEnterNecessary: ;
     s_command_line = xlenter("*COMMAND-LINE*");
     s_loadfileargs = xlenter("*LOAD-FILE-ARGUMENTS*");
     s_toplevelloop = xlenter("*TOP-LEVEL-LOOP*");
+    s_exit_functions = xlenter("SYSTEM::*EXIT-FUNCTIONS*");
+    setvalue(s_exit_functions, NIL);
 
     /* enter lambda list keywords */
     lk_optional = xlenter("&OPTIONAL");
@@ -553,8 +555,10 @@ noEnterNecessary: ;
     a_adata     = xlenter("ALLOCATED-DATA");
 #endif /* XLISP_STAT */
     a_ptr        = xlenter("SYSTEM:POINTER");
+    a_weakbox    = xlenter("SYSTEM:WEAK-BOX");
     a_tvec       = xlenter("TYPED-VECTOR");
     s_c_char     = xlenter("C-CHAR");
+    s_c_uchar    = xlenter("C-UCHAR");
     s_c_short    = xlenter("C-SHORT");
     s_c_int      = xlenter("C-INT");
     s_c_long     = xlenter("C-LONG");
