@@ -14,7 +14,7 @@ Modified by Thomas Almy and others."
 
 /* global variables */
 #ifdef SAVERESTORE
-jmp_buf top_level;
+XL_JMP_BUF top_level;
 #endif
 char *progname;  /* used for reading the symbol table - L. Tierney */
 #ifdef SAVERESTORE
@@ -22,7 +22,7 @@ char *resfile = "xlisp.wks"; /* make extern to allow setting elsewhere */
 #endif
 
 /* local variables */
-jmp_buf exit_xlisp;
+XL_JMP_BUF exit_xlisp;
 
 /* forward declarations */
 #ifdef MACINTOSH
@@ -49,7 +49,7 @@ int main(argc,argv)
 #endif /* AMIGA */
 
     /* The way out on errors */
-    i = setjmp(exit_xlisp);
+    i = XL_SETJMP(exit_xlisp);
     if (i != 0)
 	return i-1;
 
@@ -110,13 +110,13 @@ int main(argc,argv)
     /* setup initialization error handler */
     xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,(LVAL)1);
     state.transcript = transcript; state.verbose = verbose; state.i = i;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     transcript = state.transcript; verbose = state.verbose; i = state.i;
     if (sts)
 	xlfatal("fatal initialization error");
 #ifdef SAVERESTORE
     state.transcript = transcript; state.verbose = verbose; state.i = i;
-    sts = setjmp(top_level);
+    sts = XL_SETJMP(top_level);
     transcript = state.transcript; verbose = state.verbose; i = state.i;
     if (sts)
 	xlfatal("RESTORE not allowed during initialization");
@@ -147,7 +147,7 @@ int main(argc,argv)
 #ifndef MACINTOSH
     /* enter the command line (L. Tierney 9/93) */
     state.transcript = transcript; state.verbose = verbose; state.i = i;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     transcript = state.transcript; verbose = state.verbose; i = state.i;
     if (sts == 0) {
       LVAL line;
@@ -166,7 +166,7 @@ int main(argc,argv)
     /* load "init.lsp" */
     if (i) {
       state.transcript = transcript; state.verbose = verbose; state.i = i;
-      sts = setjmp(cntxt.c_jmpbuf);
+      sts = XL_SETJMP(cntxt.c_jmpbuf);
       transcript = state.transcript; verbose = state.verbose; i = state.i;
       if (sts == 0)
 	xsload("init.lsp",TRUE,FALSE);
@@ -174,7 +174,7 @@ int main(argc,argv)
 
     /* run any startup functions (L. Tierney 9/93) */
     state.transcript = transcript; state.verbose = verbose; state.i = i;
-    sts = setjmp(cntxt.c_jmpbuf);
+    sts = XL_SETJMP(cntxt.c_jmpbuf);
     transcript = state.transcript; verbose = state.verbose; i = state.i;
     if (sts == 0) {
       LVAL funs = getvalue(s_startup_functions);
@@ -193,7 +193,7 @@ int main(argc,argv)
     /* load any files mentioned on the command line */
     if (! null(getvalue(s_loadfileargs))) {
       state.transcript = transcript; state.verbose = verbose; state.i = i;
-      sts = setjmp(cntxt.c_jmpbuf);
+      sts = XL_SETJMP(cntxt.c_jmpbuf);
       transcript = state.transcript; verbose = state.verbose; i = state.i;
       if (sts == 0) {
 #ifdef MACINTOSH
@@ -209,7 +209,7 @@ int main(argc,argv)
     /* target for restore */
 #ifdef SAVERESTORE
     state.transcript = transcript; state.verbose = verbose; state.i = i;
-    sts = setjmp(top_level);
+    sts = XL_SETJMP(top_level);
     transcript = state.transcript; verbose = state.verbose; i = state.i;
     if (sts)
 	xlbegin(&cntxt, CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL, s_true);
@@ -219,7 +219,7 @@ int main(argc,argv)
     for (;;) {
 
 	/* setup the error return */
-	if (setjmp(cntxt.c_jmpbuf)) {
+	if (XL_SETJMP(cntxt.c_jmpbuf)) {
 	    setvalue(s_evalhook,NIL);
 	    setvalue(s_applyhook,NIL);
 	    xltrcindent = 0;
@@ -345,19 +345,41 @@ VOID xlfatal P1C(char *, msg)
     wrapup();
 }
 
+/* do-exits - run user exit functions */
+VOID do_exits(V)
+{
+  CONTEXT cntxt;
+
+  xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,s_true);
+  XL_SETJMP(cntxt.c_jmpbuf);
+
+  while (s_exit_functions != NULL && consp(getvalue(s_exit_functions))) {
+    FRAMEP newfp;
+    LVAL func = car(getvalue(s_exit_functions));
+    setvalue(s_exit_functions, cdr(getvalue(s_exit_functions)));
+    newfp = xlsp;
+    pusharg(cvfixnum((FIXTYPE)(newfp - xlfp)));
+    pusharg(func);
+    pusharg(cvfixnum((FIXTYPE) 0));
+    xlfp = newfp;
+    xlapply(0);
+  }
+  xlend(&cntxt);
+}
+
 /* wrapup - clean up and exit to the operating system */
 VOID wrapup(V)
 {
   /* $putpatch.c$: "MODULE_XLISP_C_WRAPUP" */
   CONTEXT cntxt;
 
-  xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,s_true);
-  if (setjmp(cntxt.c_jmpbuf) == 0) {
+  do_exits();
+  if (XL_SETJMP(cntxt.c_jmpbuf) == 0) {
     if (tfp != CLOSED)
       OSCLOSE(tfp);
     osfinish();
   }
-  longjmp(exit_xlisp, 1);
+  XL_LONGJMP(exit_xlisp, 1);
 }
 
 /* xresetsystem - reset system for user top-levels */
