@@ -1108,6 +1108,15 @@ extern int stackreport(VOID);
 #define MULVALLIMIT (128)
 #endif
 #endif
+#ifndef XL_SETJMP
+#  define XL_SETJMP(env) setjmp(env)
+#endif
+#ifndef XL_LONGJMP
+#  define XL_LONGJMP(env,val) longjmp(env,val)
+#endif
+#ifndef XL_JMP_BUF
+#  define XL_JMP_BUF jmp_buf
+#endif
 
 /* useful definitions */
 #ifndef TRUE
@@ -1471,7 +1480,7 @@ typedef LVAL *FRAMEP;
 typedef struct context {
     int c_flags;                        /* context type flags */
     LVAL c_expr;                        /* expression (type dependent) */
-    jmp_buf c_jmpbuf;                   /* longjmp context */
+    XL_JMP_BUF c_jmpbuf;                /* longjmp context */
     struct context *c_xlcontext;        /* old value of xlcontext */
     LVAL **c_xlstack;			/* old value of xlstack */
     LVAL *c_xlargv;			/* old value of xlargv */
@@ -1547,6 +1556,7 @@ extern LVAL divbignum _((LVAL dividend, LVAL divisor, LVAL *remainder));
 extern VOID xlrdsave _((LVAL expr));
 extern VOID xlevsave _((LVAL expr));
 extern VOID xlfatal _((char *msg));
+extern VOID do_exits _((void));
 extern VOID wrapup _((void));
 extern int xsload _((char *name, int vflag, int pflag));
 
@@ -1642,7 +1652,7 @@ extern VOID putobj _((LVAL fptr, LVAL obj));
 extern LVAL tentry _((int ch));
 extern int xlload _((char *fname, int vflag, int pflag));
 extern int xlread _((LVAL fptr, LVAL *pval, int rflag, int pwflag));
-extern int isnumber _((char *str, LVAL *pval));
+extern int xlisnumber _((char *str, LVAL *pval));
 
 /* for xlstruct */
 extern LVAL xlrdstruct _((LVAL list));
@@ -1701,6 +1711,7 @@ extern int xlfindsymbol _((char *name, LVAL pack, LVAL *psym));
 extern LVAL xlpackagename _((LVAL pack));
 extern LVAL xlintern _((char *name, LVAL pack));
 extern LVAL xlgetpackage _((LVAL arg));
+extern LVAL xldelete1 _((LVAL x, LVAL y));
 #endif /* PACKAGES */
 
 /* external procedure declarations */
