@@ -815,7 +815,7 @@ LOCAL VOID putsymbol P3C(LVAL, fptr, char *, stri, int, flag)
 	    }
         /* check for the first character being '#'
             or string looking like a number */
-        if (*str == '#' || isnumber(str,NULL))
+        if (*str == '#' || xlisnumber(str,NULL))
             xlputc(fptr,'\\');
     }
 
