@@ -177,10 +177,10 @@ int xlload P3C(char *, fname, int, vflag, int, pflag)
     /* read, evaluate and possibly print each expression in the file */
     xlbegin(&cntxt,CF_ERROR|CF_UNWIND,s_true); /*TAA mod so file gets closed*/
 #ifdef CRAYCC
-    mask = setjmp(cntxt.c_jmpbuf); /* TAA mod -- save mask */
+    mask = XL_SETJMP(cntxt.c_jmpbuf); /* TAA mod -- save mask */
     if (mask != 0)
 #else
-    if ((mask = setjmp(cntxt.c_jmpbuf)) != 0) /* TAA mod -- save mask */
+    if ((mask = XL_SETJMP(cntxt.c_jmpbuf)) != 0) /* TAA mod -- save mask */
 #endif /* CRAYCC */
 	sts = FALSE;
     else {
@@ -300,6 +300,7 @@ LOCAL VOID cleancircle P2C(LVAL, val, LVAL, data)
   case ADATA:
   case TVEC:
   case NATPTR:
+  case WEAKBOX:
   case SYMBOL:
 #ifdef PACKAGES
   case PACKAGE:
@@ -1168,7 +1169,7 @@ LOCAL LVAL psymbol P1C(LVAL, fptr)
 
     pname(fptr,&escflag,&packindex);
     if (! null(getvalue(s_read_suppress))) return(NIL);
-    if (escflag || packindex >= 0 || !isnumber(buf,&val)) {
+    if (escflag || packindex >= 0 || !xlisnumber(buf,&val)) {
       if (packindex >= 0) {
 	/* check for zero-length name */
 	if (buf[packindex+1] == 0) xlfail("zero length name after ':'");
@@ -1214,7 +1215,7 @@ LOCAL LVAL psymbol P1C(LVAL, fptr)
     LVAL val;
     pname(fptr,&escflag);
     if (! null(getvalue(s_read_suppress))) return(NIL);
-    return (escflag || !isnumber(buf,&val) ? xlenter(buf) : val);
+    return (escflag || !xlisnumber(buf,&val) ? xlenter(buf) : val);
 }
 #endif /* PACKAGES */
 
@@ -1439,7 +1440,7 @@ LOCAL VOID badeof(V)
     xlfail("EOF reached before expression end");
 }
 
-/* isnumber - check if this string is a number */
+/* xlisnumber - check if this string is a number */
 #define DBL_DIGITS 50
 #ifdef BIGNUMS
 LOCAL int isadigit P2C(char, c, int, r)
@@ -1450,7 +1451,7 @@ LOCAL int isadigit P2C(char, c, int, r)
 	return 0;
 }
 
-int isnumber P2C(char *, str, LVAL *, pval)
+int xlisnumber P2C(char *, str, LVAL *, pval)
 {
     int dl=0, dr=0;
     char *p = str;
@@ -1569,7 +1570,7 @@ int isnumber P2C(char *, str, LVAL *, pval)
       return (TRUE);
     }
 #else
-int isnumber P2C(char *, str, LVAL *, pval)
+int xlisnumber P2C(char *, str, LVAL *, pval)
 {
   int dl=0, dr=0;
   char *p = str;
