@@ -53,7 +53,7 @@ LOCAL VOID getseqbounds P5C(unsigned *, start,
 
   if (xlgkfixnum(startkey,&arg)) {
     temp = getfixnum(arg);
-    if (temp < 0 || temp > length ) goto rangeError;
+    if (temp < 0 || temp > (FIXTYPE)length ) goto rangeError;
     *start = (unsigned)temp;
   }
   else *start = 0;
@@ -61,7 +61,7 @@ LOCAL VOID getseqbounds P5C(unsigned *, start,
   if (xlgetkeyarg(endkey, &arg) && !null(arg)) {
     if (!fixp(arg)) xlbadtype(arg);
     temp = getfixnum(arg);
-    if (temp < *start  || temp > length) goto rangeError;
+    if (temp < (FIXTYPE)*start  || temp > (FIXTYPE)length) goto rangeError;
     *end = (unsigned)temp;  
   }
   else *end = length;
@@ -101,7 +101,7 @@ LVAL xelt(V)
   case VECTOR:
   case STRING:
   case TVEC:
-    if (i >= gettvecsize(seq)) goto badindex;
+    if (i >= (FIXTYPE)gettvecsize(seq)) goto badindex;
     return (gettvecelement(seq,(int)i));
   default:
     xlbadtype(seq);
@@ -825,7 +825,7 @@ LOCAL LVAL remif P3C(int, tresult, int, expr, int, destruct)
       for (i = j = l - 1; i != -1; i--) {
 	elt = gettvecelement(seq,i);
 	if (i < start || i >= end || /* copy if out of range */
-	    count == j-i || ! remtest(x,elt,fcn,kfcn)) {
+	    count == (FIXTYPE)(j-i) || ! remtest(x,elt,fcn,kfcn)) {
 	  if (i != j) settvecelement(seq,j,elt);
 	  j--;
 	}
@@ -842,7 +842,7 @@ LOCAL LVAL remif P3C(int, tresult, int, expr, int, destruct)
       for (i = j = 0; i < l; i++) {
 	elt = gettvecelement(seq, i);
 	if (i < start || i >= end || /* copy if out of range */
-	    count == i-j || ! remtest(x,elt,fcn,kfcn)) {
+	    count == (FIXTYPE)(i-j) || ! remtest(x,elt,fcn,kfcn)) {
 	  if (i != j) settvecelement(seq,j,elt);
 	  j++;
 	}
