@@ -13,10 +13,10 @@
 #define BANNER  "XLISP-PLUS version 3.04, Copyright (c) 1988, by David Betz\n\
 As modified by Thomas Almy"
 
-jmp_buf sysFailure;
+XL_JMP_BUF sysFailure;
 
 #ifdef SAVERESTORE
-jmp_buf top_level;
+XL_JMP_BUF top_level;
 VOID freeimage _((void));
 #endif
 LVAL getstroutput _((LVAL stream));
@@ -44,8 +44,8 @@ int initXlisp P1C(char *, resfile)
 
   /* setup initialization error handler with phoney, non NIL "true" */
   xlbegin(&cntxt,CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL,(LVAL)1);
-  if (setjmp(cntxt.c_jmpbuf)) return (1);
-  if (setjmp(sysFailure)) return (3);
+  if (XL_SETJMP(cntxt.c_jmpbuf)) return (1);
+  if (XL_SETJMP(sysFailure)) return (3);
 
   /* initialize xlisp */
 #ifdef SAVERESTORE
@@ -58,7 +58,7 @@ int initXlisp P1C(char *, resfile)
   if (i) {			/* need to load init.lsp */
     xlbegin(&cntxt, CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL, s_true);
 
-    if (setjmp(cntxt.c_jmpbuf) != 0) {
+    if (XL_SETJMP(cntxt.c_jmpbuf) != 0) {
       xlend(&cntxt);
       return (2);
     }
@@ -88,20 +88,20 @@ int execXlisp P4C(char *, str,     /* string to execute */
     
   xlbegin(&cntxt, CF_TOPLEVEL|CF_CLEANUP|CF_BRKLEVEL, s_true);
 
-  if (setjmp(sysFailure)) {
+  if (XL_SETJMP(sysFailure)) {
     xlend(&cntxt);
     xlpopn(2);
     return 2;
   }
 
-  if (setjmp(top_level)) {
+  if (XL_SETJMP(top_level)) {
     xlend(&cntxt);
     xlpopn(2);
     return 3;
   }
     
   /* setup the error return */
-  if (setjmp(cntxt.c_jmpbuf)) {
+  if (XL_SETJMP(cntxt.c_jmpbuf)) {
     xlend(&cntxt);
     setvalue(s_evalhook,NIL);
     setvalue(s_applyhook,NIL);
@@ -164,14 +164,14 @@ VOID xlfatal P1C(char *, msg)
 {
   xoserror(msg);
   wrapupXlisp();
-  longjmp(sysFailure,1);
+  XL_LONGJMP(sysFailure,1);
 }
 
 /* Terminate execution */
 VOID wrapup(V)
 {
   wrapupXlisp();
-  longjmp(sysFailure,1);
+  XL_LONGJMP(sysFailure,1);
 }
 
 /* xlrdsave - save the last expression returned by the reader */
