@@ -102,12 +102,12 @@ extern LVAL PointToList _((Point pt));
 extern int dialog_p _((LVAL x));
 extern LVAL xsgetdialog _((void));
 extern int dialog_item_p _((LVAL x));
-extern button_item_p _((LVAL x));
-extern toggle_item_p _((LVAL x));
-extern text_item_p _((LVAL x));
-extern choice_item_p _((LVAL x));
-extern scroll_item_p _((LVAL x));
-extern list_item_p _((LVAL x));
+extern int button_item_p _((LVAL x));
+extern int toggle_item_p _((LVAL x));
+extern int text_item_p _((LVAL x));
+extern int choice_item_p _((LVAL x));
+extern int scroll_item_p _((LVAL x));
+extern int list_item_p _((LVAL x));
 extern LVAL xsgetdialogitem _((void));
 extern LVAL xsgetbuttonitem _((void));
 extern LVAL xsgettoggleitem _((void));
@@ -347,7 +347,7 @@ extern VOID IViewDataCuePoints _((IViewData data, unsigned var,
 extern VOID IViewSetShowingLabels _((IVIEW_WINDOW w, int show));
 extern int IViewShowingLabels _((IVIEW_WINDOW w));
 extern VOID IViewSetFixedAspect _((IVIEW_WINDOW w, int fixed));
-extern IViewFixedAspect _((IVIEW_WINDOW w));
+extern int IViewFixedAspect _((IVIEW_WINDOW w));
 extern VOID IViewSetMouseMode _((IVIEW_WINDOW w, MouseMode mode));
 extern VOID IViewSetData _((IVIEW_WINDOW w, IViewData data));
 extern VOID IViewSetScale _((IVIEW_WINDOW w, unsigned var, double scale));
@@ -783,5 +783,7 @@ extern LVAL string2stream(char *);
 extern LVAL readevalstream(LVAL);
 extern void MSWCloseHelp(void);
 extern BOOL InitApplResizeBrush(HANDLE hInstance);
+extern BOOL StGwPrinting(StGWWinInfo *gwinfo);
+extern void StGwSetPrintingDC(StGWWinInfo *gwinfo, HDC hdc);
 #endif /* _Windows */
 #endif /* XLSTAT_H */
