@@ -409,7 +409,14 @@ VOID xlprstruct P4C(LVAL, fptr, LVAL, vptr, FIXTYPE, plevel, int, flag)
     int i,n;
     FRAMEP newfp;
 
-    next = xlgetprop(getelement(vptr,0), s_prntfunc);
+    {
+      LVAL type = getelement(vptr,0);
+      next = xlgetprop(type, s_prntfunc);
+      while (null(next) && ! null(type)) {
+	type = xlgetprop(type,s_strinclude);
+	next = xlgetprop(type, s_prntfunc);
+      }
+    }
     if (!null(next)) { /* Ken Whedbee addition */
         newfp = xlsp;
         pusharg(cvfixnum((FIXTYPE)(newfp - xlfp)));
