@@ -129,6 +129,7 @@ LVAL xtype(V)
     case ADATA:		return (a_adata);
 #endif /* XLISP_STAT */
     case NATPTR:	return (a_ptr);
+    case WEAKBOX:	return (a_weakbox);
     case TVEC:		return (a_tvec);
 #ifdef BYTECODE
     case BCCLOSURE:	return (a_bcclosure);
@@ -173,6 +174,7 @@ int xlcvttype P1C(LVAL, arg)  /* find type of argument and return it */
   if (arg == a_adata)     return ADATA;
 #endif /* XLISP_STAT */
   if (arg == a_ptr)       return NATPTR;
+  if (arg == a_weakbox)   return WEAKBOX;
   if (arg == a_tvec)      return TVEC;
 #ifdef BYTECODE
   if (arg == a_bcclosure) return BCCLOSURE;
